# -*- coding: utf-8 -*-
"""
Pygifconvt: a very serious Python library for image to gif converter

"""
__title__ = "Pygifconvt_SW"
__author__ = "Eunki7"
__license__ = "MIT License"
__copyright__ = "Copyright 2020 Eunki7"